@@ -28,3 +28,14 @@ table! {
         updated_at -> Timestamptz,
     }
 }
+
+table! {
+    fang_periodic_tasks (id) {
+        id -> Uuid,
+        metadata -> Jsonb,
+        period_in_seconds -> Int4,
+        scheduled_at -> Nullable<Timestamptz>,
+        created_at -> Timestamptz,
+        updated_at -> Timestamptz,
+    }
+}
